.. _quick:

Quick Start Guide
=================

Install
-------

If there are wheels for your platform (mac, linux, windows on x86),
you can install ``pyspex`` via pip::

  pip install [--user] pyspex

Or with `Anaconda <http://continuum.io/downloads>`_ or
`Miniconda <http://conda.pydata.org/miniconda.html>`_::

  conda install pyspex

To install `pyspex` from source see :ref:`install`.


Core concepts
-------------

...
